@@ -1,6 +1,6 @@
 package Resque::Worker;
 {
-  $Resque::Worker::VERSION = '0.09';
+  $Resque::Worker::VERSION = '0.10';
 }
 use Any::Moose;
 with 'Resque::Encoder';
@@ -312,7 +312,12 @@ sub unregister_worker {
 sub worker_pids {
     my $self = shift;
     my @pids;
-    for ( split "\n", `ps axo pid,command | grep resque | grep -v resque-web` ) {
+
+    my $ps_command = $^O eq 'solaris'
+                ? 'ps -A -o pid,args'
+                : 'ps -A -o pid,command';
+
+    for ( split "\n", `$ps_command | grep resque | grep -v resque-web` ) {
         if ( m/^\s*(\d+)\s(.+)$/ ) {
             push @pids, $1;
         }
@@ -380,7 +385,7 @@ Resque::Worker - Does the hard work of babysitting Resque::Job's
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 ATTRIBUTES
 
